eventChannel property
The event channel used to receive native system events.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('flutter_system_events/events');
The event channel used to receive native system events.
@visibleForTesting
final eventChannel = const EventChannel('flutter_system_events/events');