FlutterSystemEventsPlatform class abstract
Platform interface for native system event implementations.
- Inheritance
-
- Object
- PlatformInterface
- FlutterSystemEventsPlatform
- Implementers
Constructors
- FlutterSystemEventsPlatform()
- Constructs a FlutterSystemEventsPlatform.
Properties
-
events
→ Stream<
SystemEvent> -
Stream of decoded platform events.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
currentBattery(
) → Future< BatteryEvent> - Returns the current battery state.
-
currentNetwork(
) → Future< NetworkEvent> - Returns the current network connectivity state.
-
currentOrientation(
) → Future< OrientationEvent> - Returns the current screen orientation.
-
currentScreenBrightness(
) → Future< ScreenEvent> - Returns the current screen brightness.
-
dispose(
) → Future< void> - Stops active platform listeners.
-
initialize(
{SystemEventsConfig config = const SystemEventsConfig.defaults()}) → Future< void> -
Starts platform listeners for the enabled event groups in
config. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterSystemEventsPlatform
-
The default instance of FlutterSystemEventsPlatform to use.
getter/setter pair