LifecycleEvent class final
Event emitted when the app lifecycle changes.
- Inheritance
-
- Object
- SystemEvent
- LifecycleEvent
Constructors
- LifecycleEvent({required LifecycleState state})
-
Creates a lifecycle event.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → LifecycleState
-
Current lifecycle state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited