MemoryEvent class final

Event emitted when memory pressure changes.

Inheritance

Constructors

MemoryEvent({required MemoryState state, required int level})
Creates a memory event.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → int
Platform-specific memory pressure level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → MemoryState
Current memory pressure state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited