OrientationEvent class final

Event emitted when the screen orientation changes.

Inheritance

Constructors

OrientationEvent({required ScreenOrientation orientation})
Creates a screen orientation event.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
orientation → ScreenOrientation
Current screen orientation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited