SystemEvent class sealed
Base type for every event emitted by SystemEvents.events.
Constructors
- SystemEvent.fromMap(Map map)
-
Decodes an event from a platform channel map.
factory
- SystemEvent.fromPayload(Object? payload)
-
Decodes an event from a platform channel payload.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited