UnknownSystemEvent class final

Event emitted when a platform payload cannot be decoded.

Inheritance

Constructors

UnknownSystemEvent({required Object? rawPayload, required String reason, Object? rawType})
Creates an unknown event wrapper.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rawPayload → Object?
Original platform payload.
final
rawType → Object?
Original event type, when provided.
final
reason → String
Human-readable decode failure reason.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited