NetworkEvent class final

Event emitted when network connectivity changes.

Inheritance

Constructors

NetworkEvent({required bool online, required NetworkType networkType})
Creates a network event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
networkType NetworkType
Current network connection type.
final
online bool
Whether a network connection is available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited