ScreenEvent class final
Event emitted when the screen state or brightness changes.
- Inheritance
-
- Object
- SystemEvent
- ScreenEvent
Constructors
- ScreenEvent({required ScreenChange change, double? brightness})
-
Creates a screen event.
const
Properties
- brightness → double?
-
Screen brightness from 0.0 to 1.0 when change is brightness.
final
- change → ScreenChange
-
Current screen event kind.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited