ThermalEvent class final
Event emitted when the device thermal state changes.
- Inheritance
-
- Object
- SystemEvent
- ThermalEvent
Constructors
- ThermalEvent({required ThermalState state})
-
Creates a thermal event.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ThermalState
-
Current device thermal state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited