TimeEvent class final

Event emitted when system time, date, or timezone changes.

Inheritance

Constructors

TimeEvent({required TimeChangeReason reason})
Creates a system time event.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → TimeChangeReason
Reason reported by the platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited