FlutterSystemEventsWeb class

A web implementation of the FlutterSystemEventsPlatform of the FlutterSystemEvents plugin.

Inheritance

Constructors

FlutterSystemEventsWeb()
Constructs a FlutterSystemEventsWeb

Properties

events Stream<SystemEvent>
Stream of decoded platform events.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

currentBattery() Future<BatteryEvent>
Returns the current battery state.
inherited
currentNetwork() Future<NetworkEvent>
Returns the current network connectivity state.
override
currentOrientation() Future<OrientationEvent>
Returns the current screen orientation.
inherited
currentScreenBrightness() Future<ScreenEvent>
Returns the current screen brightness.
inherited
dispose() Future<void>
Stops active platform listeners.
override
initialize({SystemEventsConfig config = const SystemEventsConfig.defaults()}) Future<void>
Starts platform listeners for the enabled event groups in config.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void